function showm(in,out,s,d)
% showm	- Displays stream information from mass balance simulation
% function showm(in,out,s,d)
% Displays the character variable returned by dsplay.
% Argument List:
% Argument    Gives
%   in     the inlet stream numbers.
%   out    the exit stream numbers
%    s     the number of spaces for each flow.
%    d     the number of decimals to display flows.
% ex: showm([1 2],3,10,3)
%   will display streams 1, 2 and 3 as in a mixer.
% Each flow occupies 10 spaces
%   and has three decimal places shown.
disp(dsplay(in,out,s,d))
